/*
   Support - Provides some big and little endian abstraction functions.
   Copyright (C) 1998, 1999  Caolan McNamara

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
/*
   Caolan McNamara <Caolan.McNamara@ul.ie>
   Real Life: Caolan McNamara           *  Doing: MSc in HCI
   Work: Caolan.McNamara@ul.ie          *  Phone: +353-61-202699
   URL: http://www.csn.ul.ie/~caolan    *  Sig: an oblique strategy
 */

#ifndef COLE_SUPPORT_H
#define COLE_SUPPORT_H


#include <ctype.h>

#define U8	unsigned char
#define U16	unsigned short
#define U32	unsigned int


U8 fil_sreadU8 (U8 * in);
U16 fil_sreadU16 (U8 * in);
U32 fil_sreadU32 (U8 * in);

void fil_swriteU8 (U8 * dest, U8 * src);
void fil_swriteU16 (U8 * dest, U16 * src);
void fil_swriteU32 (U8 * dest, U32 * src);

#define test(t,retval,func) \
	{ \
		if (!(t)) { \
			func; \
			verbose_wonl ("returning from "); \
			verbose_wonl (__FILE__); \
			verbose_wonl (":"); \
			verbose_d (__LINE__); \
			return retval; \
		} \
	}
#define test_call(t,typeretval) \
	{ \
		typeretval retval; \
		retval = t; \
		if (retval) return retval; \
	}

#ifdef VERBOSE
#define verbose_d(n) { printf ("%d\n", n); }
#else
#define verbose_d(n)
#endif

#ifdef VERBOSE
#define verbose(s) { printf (s); printf ("\n"); }
#define verbose_wonl(s) { printf (s); }
#else
#define verbose(s)
#define verbose_wonl(s)
#endif

#ifdef VERBOSE
#define verboseU32(expr) { printf (#expr " = 0x%08lx\n", expr); }
#else
#define verboseU32(expr)
#endif

#ifdef VERBOSE
#define verboseU16(expr) { printf (#expr " = 0x%04x\n", expr); }
#else
#define verboseU16(expr)
#endif

#ifdef VERBOSE
#define verboseS(expr) { printf (#expr " = %s\n", expr); }
#else
#define verboseS(expr)
#endif

#ifdef VERBOSE
#define verboseS_wonl(expr) { printf (#expr " = %s", expr); }
#else
#define verboseS_wonl(expr)
#endif

#ifdef VERBOSE
#define verboseU32Array(array,len) \
	{ \
		U32 temp; \
		for (temp = 0; temp < len; temp++) \
			printf (#array "[%lu] = 0x%08lx\n", temp, array [temp]); \
	}
#else
#define verboseU32Array(array,len)
#endif

#ifdef VERBOSE
/* Added and modified by Arturo Tena <arturo@directmail.org> */
/* This function comes from `biffview', wich is
   Copyright 1998, 1999 David Rysdam
   and was released under GPL version 2 */
#define verboseU8Array(rec,len,reclen)                   \
 {                                                       \
    U32 temp1;                                           \
    for (temp1 = 0; temp1 < len; temp1++)                \
    {                                                    \
      char charoutput[17];                               \
      int i;                                             \
      int poscount;                                      \
      poscount = (reclen - reclen%16) + 16;              \
      strcpy(charoutput, "                ");            \
      charoutput[16] = '\0';                             \
      for(i=0; i<poscount; i++) {                        \
        if(i<reclen){                                    \
          printf("%02x ", rec[i+temp1*reclen]);          \
          charoutput[i%16] = isprint(rec[i+temp1*reclen])?rec[i+temp1*reclen]:'.'; \
        }                                                \
        else                                             \
          printf("   ");                                 \
        if((i+1)%16==0){                                 \
          printf(" %s\n", charoutput);                   \
          strcpy(charoutput, "                ");        \
        }                                                \
      }                                                  \
    }                                                    \
 }
#else
#define verboseU8Array(rec,len,reclen)
#endif

#ifdef VERBOSE
#define warning(t) { if (!(t)) printf ("warning: %s is false\n", #t); }
#else
#define warning(t)
#endif

#endif
